==> exchangerate-client-0.1.0.tar.gz: exchangerate-client-0.1.0/setup.py <==
import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='exchangerate-client',
    author='Daniel Pham',
    author_email='tdpham1105@yahoo.com',
    description='Unofficial exchangerate.host python client library',
    keywords='exchangerate.host, exchangerate, client',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/dannyp11/exchangerate-python',
    project_urls={
        'Documentation': 'https://github.com/dannyp11/exchangerate-python',
        'Bug Reports':
        'https://github.com/dannyp11/exchangerate-python/issues',
        'Source Code': 'https://github.com/dannyp11/exchangerate-python',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=['requests'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=examplepy:main',
    # You can execute `run` in bash to run `main()` in src/examplepy/__init__.py
    #     ],
    # },
)

==> exchangerate-client-0.1.1.tar.gz: exchangerate-client-0.1.1/setup.py <==
import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='exchangerate-client',
    author='Daniel Pham',
    author_email='tdpham1105@yahoo.com',
    description='Unofficial exchangerate.host python client library',
    keywords='exchangerate.host, exchangerate, client',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/dannyp11/exchangerate-python-client',
    project_urls={
        'Documentation': 'https://github.com/dannyp11/exchangerate-python-client',
        'Bug Reports':
        'https://github.com/dannyp11/exchangerate-python-client/issues',
        'Source Code': 'https://github.com/dannyp11/exchangerate-python-client',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=['requests'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=examplepy:main',
    # You can execute `run` in bash to run `main()` in src/examplepy/__init__.py
    #     ],
    # },
)
